bayespy.nodes.ConcatGaussian
============================

.. currentmodule:: bayespy.nodes

.. autoclass:: ConcatGaussian

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~ConcatGaussian.__init__
      ~ConcatGaussian.add_plate_axis
      ~ConcatGaussian.broadcasting_multiplier
      ~ConcatGaussian.delete
      ~ConcatGaussian.get_mask
      ~ConcatGaussian.get_moments
      ~ConcatGaussian.get_shape
      ~ConcatGaussian.has_plotter
      ~ConcatGaussian.lower_bound_contribution
      ~ConcatGaussian.move_plates
      ~ConcatGaussian.plot
      ~ConcatGaussian.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~ConcatGaussian.plates
      ~ConcatGaussian.plates_multiplier
   
   